@@ -1,5 +1,7 @@
 pub mod client;
+pub mod commands;
 pub mod error;
 pub mod models;
+pub mod opt;
 pub mod request_builders;
 pub mod result;
